==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathTokenizer__24XPathToken.h <==
// class gnu.xml.xpath.XPathTokenizer$XPathToken

// class file dependencies
// @dep_class 30dc154236a11d38 gnu_xml_xpath_XPathTokenizer__24XPathToken
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathTokenizer__24XPathToken_H_
#define _JC_gnu_xml_xpath_XPathTokenizer__24XPathToken_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object;

typedef const struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *, jint);
extern void _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$_init$206934d97c5ba451(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$getText$e563ff505469c39b(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method_info$getText$e563ff505469c39b;
extern _jc_method _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods {
	struct _jc_java_lang_String$object	*(*getText$e563ff505469c39b)(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods	gnu_xml_xpath_XPathTokenizer__24XPathToken;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs {
	struct _jc_java_lang_String$object	*val;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs {
    _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs	gnu_xml_xpath_XPathTokenizer__24XPathToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs	gnu_xml_xpath_XPathTokenizer__24XPathToken;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object {
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathTokenizer__24XPathToken, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathTokenizer__24XPathToken_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/xpath/XPathTokenizer__24XPathToken.h <==
// class gnu.xml.xpath.XPathTokenizer$XPathToken

// class file dependencies
// @dep_class 30dc154236a11d38 gnu_xml_xpath_XPathTokenizer__24XPathToken
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathTokenizer__24XPathToken_H_
#define _JC_gnu_xml_xpath_XPathTokenizer__24XPathToken_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object;

typedef const struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$_init$206934d97c5ba451(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$getText$e563ff505469c39b(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method_info$getText$e563ff505469c39b;
extern _jc_method _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods {
	struct _jc_java_lang_String$object	*(*getText$e563ff505469c39b)(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vmethods	gnu_xml_xpath_XPathTokenizer__24XPathToken;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs {
	struct _jc_java_lang_String$object	*val;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs {
    _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_refs	gnu_xml_xpath_XPathTokenizer__24XPathToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$sub_nonrefs	gnu_xml_xpath_XPathTokenizer__24XPathToken;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$object {
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$vtype _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathTokenizer__24XPathToken, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathTokenizer__24XPathToken$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathTokenizer__24XPathToken_H_ */
